@@ -13,7 +13,9 @@
 #include <QUrl>
 #include <QFileInfo>
 #include <QSettings>
+#include <QString>
 #include <QMaemo5InformationBox>
+#include <QtMaemo5/QtMaemo5>
 
 MainWindow::MainWindow(QWidget *parent):
     QMainWindow(parent), ui(new Ui::MainWindow),
@@ -63,8 +65,23 @@ MainWindow::MainWindow(QWidget *parent):
     //Initial QSettings for Spin Box
     initialpsb();
 
-    //Check for existance of /tmp/flopswapint to disable pushButton
+    //Check for existance of /tmp/flopswapint for button disable
     disableStatus();
+
+    //Check for existance of /tmp/flopswapref for progress indication
+    swappingActive();
+
+    //Check QSettings for Startup Check option
+    if (settingspage->startupCheck())
+    {
+        //If true click immediately after initialization
+        ui->pushButtonSwapUsage->click();
+    }
+
+    //GUI Blocking on Swap
+    connect(m_process, SIGNAL(started()), this, SLOT(disableButtons()));
+    connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(enableButtons()));
+
 }
 
 MainWindow::~MainWindow()
@@ -144,14 +161,27 @@ void MainWindow::connectSignals()
     connect(new QShortcut(QKeySequence(Qt::Key_S), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwapUsage_clicked()));
 }
 
+//Setup QSettings for Spin Box on First Run
+void MainWindow::initialpsb()
+{
+     QSettings settings("flopswap", "flopswap");
+     if (!settings.contains("PercentForDialog"))
+     {
+       settings.setValue("PercentForDialog", 94);
+       settings.value("PercentForDialog").toInt();
+     }
+}
 
-//Initial Setup Text
+//Initial First Run Dialog Text
 void MainWindow::initialshow()
 {
    QSettings settings("flopswap", "flopswap");
 
    if (!settings.contains("InitialWarningShown"))
        {
+       //Run swapswitch QProcess to draw pushbutton status correctly on first installation
+       on_pushButtonGet_clicked();
+       //Dialog
         QMaemo5InformationBox::information(
           0,
           " <br> \
@@ -164,9 +194,10 @@ void MainWindow::initialshow()
        }
 }
 
-//Initial Warning Seen
+//Initial First Run Dialog Text Seen
 void MainWindow::initialseen()
 {
+    //Set Dialog as seen
     QSettings settings("flopswap", "flopswap");
 
     if (!settings.contains("InitialWarningShown"))
@@ -176,9 +207,10 @@ void MainWindow::initialseen()
 }
 
 
-//Eject Warning Text
+//Eject First Run Dialog Text
 void MainWindow::ejectshow()
 {
+   //Dialog
    QSettings settings("flopswap", "flopswap");
 
    if (!settings.contains("EjectWarningShown"))
@@ -197,7 +229,7 @@ void MainWindow::ejectshow()
        }
 }
 
-//Eject Warning Seen
+//Eject First Run Dialog Seen
 void MainWindow::ejectseen()
 {
     QSettings settings("flopswap", "flopswap");
@@ -208,29 +240,61 @@ void MainWindow::ejectseen()
         }
 }
 
-//Check for existance of /tmp/flopswapint for pushButton
+//Check for existance of /tmp/flopswapint to disable Buttons
 void MainWindow::disableStatus()
 {
  if ( QFileInfo("/tmp/flopswapint").exists() )
-     ui->pushButtonSwapUsage->setDisabled(true);
+   {
+        ui->pushButtonEject->setDisabled(true);
+        ui->pushButtonSwapUsage->setDisabled(true);
+   }
+ else
+   {
+        ui->pushButtonEject->setDisabled(false);
+        ui->pushButtonSwapUsage->setDisabled(false);
+   }
 }
 
-//Initial QSettings for Spin Box
-void MainWindow::initialpsb()
+//Check for existance of /tmp/flopswapref on Initial to disable Buttons
+void MainWindow::swappingActive()
 {
-     QSettings settings("flopswap", "flopswap");
-     if (!settings.contains("PercentForDialog"))
-     {
-       settings.setValue("PercentForDialog", 94);
-       settings.value("PercentForDialog").toInt();
-     }
+    if ( QFileInfo("/tmp/flopswapref").exists() )
+    {
+        disableButtons();
+        //Loop this again in 5 seconds
+        QTimer::singleShot(5000, this, SLOT(swappingActive()));
+    }
+    else
+    {
+        enableButtons();
+    }
+}
+
+//Use to disable Buttons on button press
+void MainWindow::disableButtons()
+{
+    this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+    ui->pushButtonSwap->setDisabled(true);
+    ui->pushButtonEject->setDisabled(true);
+    ui->pushButtonGet->setDisabled(true);
+    ui->pushButtonSwapUsage->setDisabled(true);
+}
+
+//Use to enable Buttons on QProcess complete
+void MainWindow::enableButtons()
+{
+    this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+    ui->pushButtonSwap->setDisabled(false);
+    ui->pushButtonEject->setDisabled(false);
+    ui->pushButtonGet->setDisabled(false);
+    ui->pushButtonSwapUsage->setDisabled(false);
+    disableStatus();
 }
 
 //Buttons
 void MainWindow::on_pushButtonSwap_clicked()
 { 
     m_process->start("sudo /opt/flopswap/script/swapswitch.sh");
-    disableStatus();
 }
 
 void MainWindow::on_pushButtonEject_clicked()
@@ -238,19 +302,16 @@ void MainWindow::on_pushButtonEject_clicked()
     ejectshow();
     m_process->start("sudo /opt/flopswap/script/swapswitchejectsd.sh");
     ejectseen();
-    disableStatus();
 }
 
 void MainWindow::on_pushButtonGet_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/catprocswap.sh");
-    disableStatus();
 }
 
 void MainWindow::on_pushButtonSwapUsage_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/swapused.sh");
-    disableStatus();
 }
 
 //Actions
