@@ -10,6 +10,7 @@ sleep 5
 #Logic
 if [ "$swap" = "$swap1" ] ;
 then
+   touch "$swaptempfile"
    $nice $xswapon $swap2
       banner "$prog"
    $nice $xswapoff $swap1
@@ -17,11 +18,14 @@ then
     if [ `awk '/dev/ {print $1}' /proc/swaps` = "$swap2" ] ;
      then
       banner "$sucess"
+      rm "$inttempfile"
+      rm "$swaptempfile"
   sleep 5
     banner "$swap2"
     fi
 elif [ `awk '/dev/ {print $1}' /proc/swaps` = "$swap2" ] ;
 then
+   touch "$swaptempfile"
    $nice $xswapon $swap1
        banner "$prog"
    $nice $xswapoff $swap2
@@ -29,6 +33,8 @@ then
     if [ `awk '/dev/ {print $1}' /proc/swaps` = "$swap1" ] ;
      then
       banner "$sucess"
+      rm "$inttempfile"
+      rm "$swaptempfile"
   sleep 5
    banner "$swap1" 
     fi
@@ -36,6 +42,7 @@ elif [ "$swap" = "$swap0" ] ;
 then
  if [ -e "$swap1" ] ;
   then
+   touch "$swaptempfile"
    $nice $xswapon $swap1
        banner "$prog"
    $nice $xswapoff $swap0
@@ -46,6 +53,8 @@ then
     if [ `awk '/dev/ {print $1}' /proc/swaps` = "$swap1" ] ;
      then
       banner "$sucess"
+      rm "$inttempfile"
+      rm "$swaptempfile"
   sleep 5
  banner "$swap1"
     fi
